diff --git a/typo3/sysext/core/Classes/Cache/Backend/SimpleFileBackend.php b/typo3/sysext/core/Classes/Cache/Backend/SimpleFileBackend.php
index 5a9f988ef637cc8842d3937e41bad4d2c951b06e..d2961ff881453fb2b33ea12e039b31c7acc74647 100644
--- a/typo3/sysext/core/Classes/Cache/Backend/SimpleFileBackend.php
+++ b/typo3/sysext/core/Classes/Cache/Backend/SimpleFileBackend.php
@@ -113,7 +113,7 @@ class SimpleFileBackend extends AbstractBackend implements PhpCapableBackendInte
      */
     public function setCacheDirectory($cacheDirectory)
     {
-        // Skip handling if directory is a stream ressource
+        // Skip handling if directory is a stream resource
         // This is used by unit tests with vfs:// directories
         if (strpos($cacheDirectory, '://')) {
             $this->temporaryCacheDirectory = $cacheDirectory;
diff --git a/typo3/sysext/core/Classes/Configuration/Loader/YamlFileLoader.php b/typo3/sysext/core/Classes/Configuration/Loader/YamlFileLoader.php
index c2b65b32900cc859acff4e7c3c77f0b323a17707..bb320e53530a6608ab1490d01f649728c7dad249 100644
--- a/typo3/sysext/core/Classes/Configuration/Loader/YamlFileLoader.php
+++ b/typo3/sysext/core/Classes/Configuration/Loader/YamlFileLoader.php
@@ -240,7 +240,7 @@ class YamlFileLoader
      */
     protected function getParts(string $placeholders): array
     {
-        // find occurences of placeholders like %some()% and %array.access%.
+        // find occurrences of placeholders like %some()% and %array.access%.
         // Only find the innermost ones, so we can nest them.
         preg_match_all(
             '/%[^(%]+?\([\'"]?([^(]*?)[\'"]?\)%|%([^%()]*?)%/',
diff --git a/typo3/sysext/core/Classes/Database/Query/BulkInsertQuery.php b/typo3/sysext/core/Classes/Database/Query/BulkInsertQuery.php
index 1388b52ed0230b51cfcb12b05adec5893737b6e4..ad2e1597bf308311d5c1562b7a9fcad4e2de1924 100644
--- a/typo3/sysext/core/Classes/Database/Query/BulkInsertQuery.php
+++ b/typo3/sysext/core/Classes/Database/Query/BulkInsertQuery.php
@@ -21,10 +21,10 @@ use Doctrine\DBAL\Connection;
  * Provides functionality to generate and execute row based bulk INSERT statements.
  *
  * Based on work by Steve Müller <st.mueller@dzh-online.de> for the Doctrine project,
- * licensend under the MIT license.
+ * licensed under the MIT license.
  *
  * This class will be removed from core and the functionality will be provided by
- * the upstream implemention once the pull request has been merged into Doctrine DBAL.
+ * the upstream implementation once the pull request has been merged into Doctrine DBAL.
  *
  * @see https://github.com/doctrine/dbal/pull/682
  * @internal
diff --git a/typo3/sysext/core/Classes/Database/ReferenceIndex.php b/typo3/sysext/core/Classes/Database/ReferenceIndex.php
index 2d1932fb3295a8d05f174c5f6a1ecb10445ccc91..88c7e20fde810f02bacd27d525432afc2941b2ae 100644
--- a/typo3/sysext/core/Classes/Database/ReferenceIndex.php
+++ b/typo3/sysext/core/Classes/Database/ReferenceIndex.php
@@ -1073,7 +1073,7 @@ class ReferenceIndex implements LoggerAwareInterface
             $cli_echo = null;
         }
         if ($cli_echo !== null) {
-            trigger_error('The second argument of ReferenceIndex->updateIndex() will not work in TYPO3 v11 anymore. Use the ProgressListener to show detailled results', E_USER_DEPRECATED);
+            trigger_error('The second argument of ReferenceIndex->updateIndex() will not work in TYPO3 v11 anymore. Use the ProgressListener to show detailed results', E_USER_DEPRECATED);
         } else {
             // default value for now
             $cli_echo = false;
diff --git a/typo3/sysext/core/Classes/Database/RelationHandler.php b/typo3/sysext/core/Classes/Database/RelationHandler.php
index 1e54b7016098890801c18a05f5cc9359603fa10b..2105f1b1c14b303bb17739cd01127b2c961bc30c 100644
--- a/typo3/sysext/core/Classes/Database/RelationHandler.php
+++ b/typo3/sysext/core/Classes/Database/RelationHandler.php
@@ -389,7 +389,7 @@ class RelationHandler
             foreach ($tempItemArray as $key => $val) {
                 // Will be set to "true" if the entry was a real table/id
                 $isSet = false;
-                // Extract table name and id. This is un the formular [tablename]_[id]
+                // Extract table name and id. This is in the formula [tablename]_[id]
                 // where table name MIGHT contain "_", hence the reversion of the string!
                 $val = strrev($val);
                 $parts = explode('_', $val, 2);
diff --git a/typo3/sysext/core/Classes/Database/Schema/EventListener/SchemaColumnDefinitionListener.php b/typo3/sysext/core/Classes/Database/Schema/EventListener/SchemaColumnDefinitionListener.php
index 168a6309644008be532825c447a3a0c9bf5d7183..06b77a0b397394e4a164f70428cd949deff69b27 100644
--- a/typo3/sysext/core/Classes/Database/Schema/EventListener/SchemaColumnDefinitionListener.php
+++ b/typo3/sysext/core/Classes/Database/Schema/EventListener/SchemaColumnDefinitionListener.php
@@ -88,24 +88,24 @@ class SchemaColumnDefinitionListener
     /**
      * Extract the field type from the definition string
      *
-     * @param string $typeDefiniton
+     * @param string $typeDefinition
      * @return string
      */
-    protected function getDatabaseType(string $typeDefiniton): string
+    protected function getDatabaseType(string $typeDefinition): string
     {
-        $dbType = strtolower($typeDefiniton);
+        $dbType = strtolower($typeDefinition);
         $dbType = strtok($dbType, '(), ');
 
         return $dbType;
     }
 
     /**
-     * @param string $typeDefiniton
+     * @param string $typeDefinition
      * @return array
      */
-    protected function getUnquotedEnumerationValues(string $typeDefiniton): array
+    protected function getUnquotedEnumerationValues(string $typeDefinition): array
     {
-        $valuesDefinition = preg_replace('#^(enum|set)\((.*)\)\s*$#i', '$2', $typeDefiniton);
+        $valuesDefinition = preg_replace('#^(enum|set)\((.*)\)\s*$#i', '$2', $typeDefinition);
         $quoteChar = $valuesDefinition[0];
         $separator = $quoteChar . ',' . $quoteChar;
 
diff --git a/typo3/sysext/core/Classes/Database/Schema/Parser/TableBuilder.php b/typo3/sysext/core/Classes/Database/Schema/Parser/TableBuilder.php
index 0b85e0b0394a682adec56ade1901169e9945cec7..6dd53545c2dffb49a3c942800d7f17ef63d3e73e 100644
--- a/typo3/sysext/core/Classes/Database/Schema/Parser/TableBuilder.php
+++ b/typo3/sysext/core/Classes/Database/Schema/Parser/TableBuilder.php
@@ -269,7 +269,7 @@ class TableBuilder
         string $indexName = null
     ) {
         $foreignTableName = $referenceDefinition->tableName->getQuotedName();
-        $foreignColumNames = array_map(
+        $foreignColumnNames = array_map(
             function (IndexColumnName $columnName) {
                 return $columnName->columnName->getQuotedName();
             },
@@ -284,7 +284,7 @@ class TableBuilder
         $this->table->addForeignKeyConstraint(
             $foreignTableName,
             $localColumnNames,
-            $foreignColumNames,
+            $foreignColumnNames,
             $options,
             $indexName
         );
diff --git a/typo3/sysext/core/Classes/Mail/Rfc822AddressesParser.php b/typo3/sysext/core/Classes/Mail/Rfc822AddressesParser.php
index e662e97d339e36db6cf201edd22b081863f3dbc9..06db691af6bc2ea0b1dead5ba3c5cbca0b7fd669 100644
--- a/typo3/sysext/core/Classes/Mail/Rfc822AddressesParser.php
+++ b/typo3/sysext/core/Classes/Mail/Rfc822AddressesParser.php
@@ -46,7 +46,7 @@ namespace TYPO3\CMS\Core\Mail;
  *
  * What is it?
  *
- * This class will take an address string, and parse it into it's consituent
+ * This class will take an address string, and parse it into it's constituent
  * parts, be that either addresses, groups, or combinations. Nested groups
  * are not supported. The structure it returns is pretty straight forward,
  * and is similar to that provided by the imap_rfc822_parse_adrlist(). Use
diff --git a/typo3/sysext/core/Classes/Resource/AbstractFile.php b/typo3/sysext/core/Classes/Resource/AbstractFile.php
index 325255f1611c74a74f41c05f2ed01bfbd30c4d9e..a26d3a89bede392eb6af057f64bb7f629130a3ec 100644
--- a/typo3/sysext/core/Classes/Resource/AbstractFile.php
+++ b/typo3/sysext/core/Classes/Resource/AbstractFile.php
@@ -354,7 +354,7 @@ abstract class AbstractFile implements FileInterface
     }
 
     /****************************************
-     * STORAGE AND MANAGEMENT RELATED METHDOS
+     * STORAGE AND MANAGEMENT RELATED METHODS
      ****************************************/
 
     /**
diff --git a/typo3/sysext/core/Classes/Resource/Collection/AbstractFileCollection.php b/typo3/sysext/core/Classes/Resource/Collection/AbstractFileCollection.php
index dfe486695d5c9339f768f425bdac57df9a6f2a76..dcb7192b14a86511fcf6282a74b3138098a2510f 100644
--- a/typo3/sysext/core/Classes/Resource/Collection/AbstractFileCollection.php
+++ b/typo3/sysext/core/Classes/Resource/Collection/AbstractFileCollection.php
@@ -196,7 +196,7 @@ abstract class AbstractFileCollection extends \TYPO3\CMS\Core\Collection\Abstrac
     }
 
     /**
-     * Adds all files of another collection to the corrent one.
+     * Adds all files of another collection to the current one.
      *
      * @param CollectionInterface $other
      */
diff --git a/typo3/sysext/core/Classes/Resource/Event/AfterResourceStorageInitializationEvent.php b/typo3/sysext/core/Classes/Resource/Event/AfterResourceStorageInitializationEvent.php
index 9bd8cb33e03c34e894c9ee2dbbea31dbf2e4ebbc..95377bfddb74b54edb58ca49c8d8402dc8f1efca 100644
--- a/typo3/sysext/core/Classes/Resource/Event/AfterResourceStorageInitializationEvent.php
+++ b/typo3/sysext/core/Classes/Resource/Event/AfterResourceStorageInitializationEvent.php
@@ -21,7 +21,7 @@ use TYPO3\CMS\Core\Resource\ResourceStorage;
 /**
  * This event is fired after a resource object was built/created.
  *
- * Custom handlers can be initialized at this moment for any kind of rource  as well.
+ * Custom handlers can be initialized at this moment for any kind of source  as well.
  */
 final class AfterResourceStorageInitializationEvent
 {
diff --git a/typo3/sysext/core/Classes/Resource/FileReference.php b/typo3/sysext/core/Classes/Resource/FileReference.php
index ae970459d88e0f39aa8c43254e944d41b8b4e46a..2c6669b99417e2783249f4659c448ca32469c331 100644
--- a/typo3/sysext/core/Classes/Resource/FileReference.php
+++ b/typo3/sysext/core/Classes/Resource/FileReference.php
@@ -372,7 +372,7 @@ class FileReference implements FileInterface
     }
 
     /****************************************
-     * STORAGE AND MANAGEMENT RELATED METHDOS
+     * STORAGE AND MANAGEMENT RELATED METHODS
      ****************************************/
     /**
      * Get the storage the original file is located in
diff --git a/typo3/sysext/core/Classes/Resource/ProcessedFile.php b/typo3/sysext/core/Classes/Resource/ProcessedFile.php
index f8e85570288be4011fb8a77da09e57607ab22186..06d12c14d0b70f2da55ca9c0be9435ce0b4b9833 100644
--- a/typo3/sysext/core/Classes/Resource/ProcessedFile.php
+++ b/typo3/sysext/core/Classes/Resource/ProcessedFile.php
@@ -199,7 +199,7 @@ class ProcessedFile extends AbstractFile
     }
 
     /*****************************************
-     * STORAGE AND MANAGEMENT RELATED METHDOS
+     * STORAGE AND MANAGEMENT RELATED METHODS
      *****************************************/
     /**
      * Returns TRUE if this file is indexed
diff --git a/typo3/sysext/core/Classes/Resource/ResourceCompressor.php b/typo3/sysext/core/Classes/Resource/ResourceCompressor.php
index f45f685e02262c0181b0fcaacf56114cbfa604af..6c3f4999bb3420874c72af87bc640b46df75bb01 100644
--- a/typo3/sysext/core/Classes/Resource/ResourceCompressor.php
+++ b/typo3/sysext/core/Classes/Resource/ResourceCompressor.php
@@ -238,7 +238,7 @@ class ResourceCompressor
         if (empty($type)) {
             throw new \InvalidArgumentException('No valid file type given for files to be merged.', 1308957498);
         }
-        // we add up the filenames, filemtimes and filsizes to later build a checksum over
+        // we add up the filenames, filemtimes and filesizes to later build a checksum over
         // it and include it in the temporary file name
         $unique = '';
         foreach ($filesToInclude as $key => $filename) {
diff --git a/typo3/sysext/core/Classes/Utility/MailUtility.php b/typo3/sysext/core/Classes/Utility/MailUtility.php
index e2d62f5b90a26f73481059d41adc2602f1acefb0..8ef6cf2cb6598441cdbaeb6a93e7aaa6f348a37c 100644
--- a/typo3/sysext/core/Classes/Utility/MailUtility.php
+++ b/typo3/sysext/core/Classes/Utility/MailUtility.php
@@ -113,7 +113,7 @@ class MailUtility
      * @param string $str The string to break up
      * @param string $newlineChar The string to implode the broken lines with (default/typically \n)
      * @param int $lineWidth The line width
-     * @return string Reformated text
+     * @return string Reformatted text
      */
     public static function breakLinesForEmail($str, $newlineChar = LF, $lineWidth = 76)
     {
diff --git a/typo3/sysext/core/Documentation/Changelog/10.0/Breaking-87193-DeprecatedFunctionalityRemoved.rst b/typo3/sysext/core/Documentation/Changelog/10.0/Breaking-87193-DeprecatedFunctionalityRemoved.rst
index 03733ff8b1d89a20aa9b0a8d5ba13c45ba32dee4..8ab41efc9524ae8b2a16ddae1310893865cad91c 100644
--- a/typo3/sysext/core/Documentation/Changelog/10.0/Breaking-87193-DeprecatedFunctionalityRemoved.rst
+++ b/typo3/sysext/core/Documentation/Changelog/10.0/Breaking-87193-DeprecatedFunctionalityRemoved.rst
@@ -1513,6 +1513,6 @@ The following global instances have been removed:
 Impact
 ======
 
-Instantiating or requiring the PHP classes or calling the PHP methods directly will trigger PHP :php:`E_ERRER` errors.
+Instantiating or requiring the PHP classes or calling the PHP methods directly will trigger PHP :php:`E_ERROR` errors.
 
 .. index:: Backend, CLI, FlexForm, Fluid, Frontend, JavaScript, LocalConfiguration, PHP-API, TCA, TSConfig, TypoScript, PartiallyScanned
diff --git a/typo3/sysext/core/Documentation/Changelog/10.1/Important-89122-UnifiedEvaluationOfVersionedRecordsInWorkspaces.rst b/typo3/sysext/core/Documentation/Changelog/10.1/Important-89122-UnifiedEvaluationOfVersionedRecordsInWorkspaces.rst
index 5f6bfa43b66b545e2c52a8e10eb97d87914552c7..706009475dbba240a35116c13a3aae36070bb8a8 100644
--- a/typo3/sysext/core/Documentation/Changelog/10.1/Important-89122-UnifiedEvaluationOfVersionedRecordsInWorkspaces.rst
+++ b/typo3/sysext/core/Documentation/Changelog/10.1/Important-89122-UnifiedEvaluationOfVersionedRecordsInWorkspaces.rst
@@ -31,7 +31,7 @@ If this is not possible when building custom queries without restrictions, it is
 
 - t3ver_oid>0 = identifying a versioned record that has a counterpart in the live workspace
 - t3ver_wsid=13 - identifying a versioned record or placeholder that resides in a specific workspace (in this case "13")
-- t3ver_state IN (0,-1) AND t3ver_wisd IN (0,13) - to fetch records including "new record" placeholders
+- t3ver_state IN (0,-1) AND t3ver_wsid IN (0,13) - to fetch records including "new record" placeholders
 
 Checking for "pid = -1" is not recommended anymore - using the restrictions and custom query information can be
 used in previous TYPO3 versions already.
diff --git a/typo3/sysext/core/Documentation/Changelog/10.2/Deprecation-89331-FormEngineLegacyFunctions.rst b/typo3/sysext/core/Documentation/Changelog/10.2/Deprecation-89331-FormEngineLegacyFunctions.rst
index d3ca39784bf1ebe6ac9cdbd3f6b7eb2c48adbf20..30476545f58b2eb1597b4bda27cfa18df2dc44d8 100644
--- a/typo3/sysext/core/Documentation/Changelog/10.2/Deprecation-89331-FormEngineLegacyFunctions.rst
+++ b/typo3/sysext/core/Documentation/Changelog/10.2/Deprecation-89331-FormEngineLegacyFunctions.rst
@@ -45,7 +45,7 @@ use the according replacements:
 * :js:`setFormValueOpenBrowser()` - use :js:`FormEngine.openPopupWindow()` instead
 * :js:`setFormValueFromBrowseWin()` - use :js:`FormEngine.setSelectOptionFromExternalSource()` instead
 * :js:`setHiddenFromList()` - use :js:`FormEngine.updateHiddenFieldValueFromSelect()` instead
-* :js:`setFormValueManipulate()` - no replacement, this is interal logic for form controls separated into according modules
+* :js:`setFormValueManipulate()` - no replacement, this is internal logic for form controls separated into according modules
 * :js:`setFormValue_getFObj()` - use :js:`FormEngine.getFormElement()` instead
 
 If :js:`setFormValueFromBrowseWin()` is not used within a FormEngine context, it is possible to listen to the
diff --git a/typo3/sysext/core/Documentation/Changelog/10.2/Important-89764-IncompatibleEnvironmentRelatedDependencyInjectionServicesHaveBeenRemoved.rst b/typo3/sysext/core/Documentation/Changelog/10.2/Important-89764-IncompatibleEnvironmentRelatedDependencyInjectionServicesHaveBeenRemoved.rst
index 98fa9138242ae04df52312ab0a8f71bbd085acdb..f1a50170a6879cb061890ec14f46eec36f98b2fa 100644
--- a/typo3/sysext/core/Documentation/Changelog/10.2/Important-89764-IncompatibleEnvironmentRelatedDependencyInjectionServicesHaveBeenRemoved.rst
+++ b/typo3/sysext/core/Documentation/Changelog/10.2/Important-89764-IncompatibleEnvironmentRelatedDependencyInjectionServicesHaveBeenRemoved.rst
@@ -17,7 +17,7 @@ Affected dependency injection services are the following boolean services:
 - env.is_unix
 - env.is_windows
 - env.is_cli
-- env.is_compoer_mode
+- env.is_composer_mode
 
 The services variables can be substituted by using dynamic Symfony
 environment parameters:
diff --git a/typo3/sysext/core/Resources/Private/Charsets/csconvtbl/readme.txt b/typo3/sysext/core/Resources/Private/Charsets/csconvtbl/readme.txt
index f665e2fad877cccb1344f22618f0c46cf5dd71a2..801853bcb0a906cd685a669632c65ba9b7b6e464 100644
--- a/typo3/sysext/core/Resources/Private/Charsets/csconvtbl/readme.txt
+++ b/typo3/sysext/core/Resources/Private/Charsets/csconvtbl/readme.txt
@@ -16,7 +16,7 @@ http://www.unicode.org/Public/MAPPINGS/
 
 
 PARSING:
-The conversion table files are parsed line by line, extracting by either of these formulars:
+The conversion table files are parsed line by line, extracting by either of these formulas:
 
 Syntax 1:
 [Local charset value, hex] = U+[UNICODE hex number] : [descriptive text, ignored]
diff --git a/typo3/sysext/core/Resources/Private/Language/locallang_csh_corebe.xlf b/typo3/sysext/core/Resources/Private/Language/locallang_csh_corebe.xlf
index 1106fd9bb44452c04a4690c644f3e3581e39362b..53d6437abc5312e50ad5ffc373b5e8bb5e2070f0 100644
--- a/typo3/sysext/core/Resources/Private/Language/locallang_csh_corebe.xlf
+++ b/typo3/sysext/core/Resources/Private/Language/locallang_csh_corebe.xlf
@@ -176,7 +176,7 @@ If you click the folder title in the Folder Tree you will see the sub-module loa
 The Web&gt;List module might not be the best "view" of the content on a page for any situation. For instance if you want to manage website content on a page (Content Elements) you should rather use the "Web&gt;Page" module which is designed to display content elements more optimized. But the List module will always give you access to whatever is on the page in a basic way if no better module is available for management.
 
 &lt;b&gt;Single-table mode&lt;/b&gt;
-If you click the tabel title in the listing you will enter single-table mode. In this mode you can select additional fields from the table to show in the listing. Also you will get additional editing facilities, for instance you will be able to edit multiple records at a time and even only certain fields from those records. See the screenshot for more details.</source>
+If you click the table title in the listing you will enter single-table mode. In this mode you can select additional fields from the table to show in the listing. Also you will get additional editing facilities, for instance you will be able to edit multiple records at a time and even only certain fields from those records. See the screenshot for more details.</source>
 			</trans-unit>
 			<trans-unit id="_list_module.seeAlso" resname="_list_module.seeAlso" xml:space="preserve">
 				<source>xMOD_csh_corebe:pagetree,
@@ -626,7 +626,7 @@ If you click the icon of a file you will see a menu pop up with menu items relat
 
 &lt;b&gt;The "TEMP" folder&lt;/b&gt;
 There is a special folder, the "TEMP" folder. This is meant to be used for temporary uploads of files that are going to be attached to TYPO3 records later. Content in the TEMP folder should be possible to flush once in a while when the folder becomes too crowded with files. So don't store persistent data in there!
-The actual folder name is actually "_temp_". The interface will just interprete this with "TEMP" in bold.
+The actual folder name is actually "_temp_". The interface will just interpret this with "TEMP" in bold.
 The same applies to folders named "_recycler_" - they will be trash cans in the folder tree.</source>
 			</trans-unit>
 			<trans-unit id="_filelist_module.seeAlso" resname="_filelist_module.seeAlso" xml:space="preserve">
diff --git a/typo3/sysext/core/Resources/Private/Language/locallang_csh_pages.xlf b/typo3/sysext/core/Resources/Private/Language/locallang_csh_pages.xlf
index 489468040754c3a28b50f1f67d86c6cfa1ba73b2..63ac57439843423bca280a4e0851ee547d6770b8 100644
--- a/typo3/sysext/core/Resources/Private/Language/locallang_csh_pages.xlf
+++ b/typo3/sysext/core/Resources/Private/Language/locallang_csh_pages.xlf
@@ -24,9 +24,9 @@
 &lt;b&gt;Special&lt;/b&gt;
 'Folder' is a page type which is not shown as a webpage but is instead stores records of your choice.
 'Recycler' is a garbage can. Pages and records in the Recycler are not visible in the Frontend.
-'Menu Separator' is only useful if your Frontend memus are programmed to use it. It does not represent a page with content but is intended to be an unclickable placeholder in the menu.
+'Menu Separator' is only useful if your Frontend menus are programmed to use it. It does not represent a page with content but is intended to be an unclickable placeholder in the menu.
 
-&lt;b&gt;Notice&lt;/b&gt; Each Page Type is represented by a unique icon. The available page types can be restricted for users so all of the options described above may not be visible. Finally, particuilar record typoes may only be allowed on certain page types, but any record can be placed in a 'Folder.'</source>
+&lt;b&gt;Notice&lt;/b&gt; Each Page Type is represented by a unique icon. The available page types can be restricted for users so all of the options described above may not be visible. Finally, particular record types may only be allowed on certain page types, but any record can be placed in a 'Folder.'</source>
 			</trans-unit>
 			<trans-unit id="_doktype.seeAlso" resname="_doktype.seeAlso" xml:space="preserve">
 				<source>pages:shortcut,
diff --git a/typo3/sysext/core/Tests/Acceptance/Backend/Template/TemplateCest.php b/typo3/sysext/core/Tests/Acceptance/Backend/Template/TemplateCest.php
index abfdd3255b79aa25826212e97f65f87dbd942988..c449251dca38855972c278726f343517693aacec 100644
--- a/typo3/sysext/core/Tests/Acceptance/Backend/Template/TemplateCest.php
+++ b/typo3/sysext/core/Tests/Acceptance/Backend/Template/TemplateCest.php
@@ -103,7 +103,7 @@ class TemplateCest
         $I->waitForElementNotVisible('#t3js-ui-block');
 
         $I->wantTo('change the setup, save the template and close the form');
-        // grap and fill setup textarea
+        // grab and fill setup textarea
         $config = $I->grabTextFrom('//textarea[@data-formengine-input-name="data[sys_template][1][config]"]');
         $config = str_replace('HELLO WORLD!', 'Hello Acceptance Test!', $config);
         $I->fillField('//textarea[@data-formengine-input-name="data[sys_template][1][config]"]', $config);
diff --git a/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/BookmarkCest.php b/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/BookmarkCest.php
index 48798b94d81949bbe40d0fa51e79caa87656e5a2..0036115dcd75a83ad3f5c1fc944b2d08f5fcd7ec 100644
--- a/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/BookmarkCest.php
+++ b/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/BookmarkCest.php
@@ -91,7 +91,7 @@ class BookmarkCest
 
         // @test complete test when https://forge.typo3.org/issues/75689 is fixed
         $scenario->comment(
-            'Tests for deleting the item in the list and readding it are missing ' .
+            'Tests for deleting the item in the list and re-adding it are missing ' .
             'as this is currently broken in the core. See https://forge.typo3.org/issues/75689'
         );
 
diff --git a/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/ModuleMenuButtonCest.php b/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/ModuleMenuButtonCest.php
index 4a7baaebdaeb284ed51cabc2f7f41ac4c9dbef95..40a1a15999fd32f327820ce299199eee5240fdc7 100644
--- a/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/ModuleMenuButtonCest.php
+++ b/typo3/sysext/core/Tests/Acceptance/Backend/Topbar/ModuleMenuButtonCest.php
@@ -33,7 +33,7 @@ class ModuleMenuButtonCest
     /**
      * @param BackendTester $I
      */
-    public function checkModelMenuButtomFromBigToSmallScreen(BackendTester $I)
+    public function checkModelMenuButtonFromBigToSmallScreen(BackendTester $I)
     {
         $I->wantTo('see the module menu button behavior when shrinking the window');
 
@@ -64,7 +64,7 @@ class ModuleMenuButtonCest
     /**
      * @param BackendTester $I
      */
-    public function checkModelMenuButtomFromSmallToBigScreen(BackendTester $I)
+    public function checkModelMenuButtonFromSmallToBigScreen(BackendTester $I)
     {
         $I->wantTo('see the module menu button behavior when enlarging the window');
 
diff --git a/typo3/sysext/core/Tests/Acceptance/Install.suite.yml b/typo3/sysext/core/Tests/Acceptance/Install.suite.yml
index ceefe0f4d3dfcf34f5715b1558bfc3bcaf66c511..6b578ed57e4d30768af68241cbbaad6e6b088573 100644
--- a/typo3/sysext/core/Tests/Acceptance/Install.suite.yml
+++ b/typo3/sysext/core/Tests/Acceptance/Install.suite.yml
@@ -19,7 +19,7 @@ env:
           capabilities:
             # Disable the "scroll to element before clicking" behavior as this breaks tests
             # where for example a fixed docbar is used. Selenium scrolls to the element before
-            # clicking it and then complains that it can't click the element because another elemnt
+            # clicking it and then complains that it can't click the element because another element
             # is overlaying it.
             # You have to ensure that the element is in the viewport by your own before clicking it!
             # You can simply do that by scrolling to it.
diff --git a/typo3/sysext/core/Tests/Functional/Cache/Backend/RedisBackendTest.php b/typo3/sysext/core/Tests/Functional/Cache/Backend/RedisBackendTest.php
index 8c0aad0b867fe543d2fd5e81ae2be4abc66a8b6c..8727e5009356cb0eafb187493022a369f8d91e19 100644
--- a/typo3/sysext/core/Tests/Functional/Cache/Backend/RedisBackendTest.php
+++ b/typo3/sysext/core/Tests/Functional/Cache/Backend/RedisBackendTest.php
@@ -494,12 +494,12 @@ class RedisBackendTest extends FunctionalTestCase
         $identifier = StringUtility::getUniqueId('identifier');
         $data = 'some data ' . microtime();
         $subject->set($identifier, $data);
-        $uncompresedStoredData = '';
+        $uncompressedStoredData = '';
         try {
-            $uncompresedStoredData = @gzuncompress($redis->get('identData:' . $identifier));
+            $uncompressedStoredData = @gzuncompress($redis->get('identData:' . $identifier));
         } catch (\Exception $e) {
         }
-        self::assertEquals($data, $uncompresedStoredData, 'Original and compressed data don\'t match');
+        self::assertEquals($data, $uncompressedStoredData, 'Original and compressed data don\'t match');
     }
 
     /**
diff --git a/typo3/sysext/core/Tests/Functional/Fixtures/Extensions/test_datahandler/Configuration/TCA/tx_testdatahandler_element.php b/typo3/sysext/core/Tests/Functional/Fixtures/Extensions/test_datahandler/Configuration/TCA/tx_testdatahandler_element.php
index 2a092df9fa52224c5bcdafe51aafdc414ea17834..c26f1149587c831aec25270e6c7d7686c12e1f97 100644
--- a/typo3/sysext/core/Tests/Functional/Fixtures/Extensions/test_datahandler/Configuration/TCA/tx_testdatahandler_element.php
+++ b/typo3/sysext/core/Tests/Functional/Fixtures/Extensions/test_datahandler/Configuration/TCA/tx_testdatahandler_element.php
@@ -1,7 +1,7 @@
 <?php
 return [
     'ctrl' => [
-        'title' => 'DataHander Test Element',
+        'title' => 'DataHandler Test Element',
         'label' => 'title',
         'tstamp' => 'tstamp',
         'crdate' => 'crdate',
diff --git a/typo3/sysext/core/Tests/Unit/Cache/Backend/FileBackendTest.php b/typo3/sysext/core/Tests/Unit/Cache/Backend/FileBackendTest.php
index 9d4113b24d5c4a2a76b42ea0341987d059853483..f03bd7cb634e10734792d160fbdc4dd5ed4f8006 100644
--- a/typo3/sysext/core/Tests/Unit/Cache/Backend/FileBackendTest.php
+++ b/typo3/sysext/core/Tests/Unit/Cache/Backend/FileBackendTest.php
@@ -501,8 +501,8 @@ class FileBackendTest extends UnitTestCase
     public function invalidEntryIdentifiers(): array
     {
         return [
-            'trailing slash' => ['/myIdentifer'],
-            'trailing dot and slash' => ['./myIdentifer'],
+            'trailing slash' => ['/myIdentifier'],
+            'trailing dot and slash' => ['./myIdentifier'],
             'trailing two dots and slash' => ['../myIdentifier'],
             'trailing with multiple dots and slashes' => ['.././../myIdentifier'],
             'slash in middle part' => ['my/Identifier'],
diff --git a/typo3/sysext/core/Tests/Unit/Cache/Backend/WincacheBackendTest.php b/typo3/sysext/core/Tests/Unit/Cache/Backend/WincacheBackendTest.php
index de21aa4b9ce270598dace94c0b5a930aed388aac..609a2e33c179ac9cbd246d2a35a8b5cbad8f95f5 100644
--- a/typo3/sysext/core/Tests/Unit/Cache/Backend/WincacheBackendTest.php
+++ b/typo3/sysext/core/Tests/Unit/Cache/Backend/WincacheBackendTest.php
@@ -62,7 +62,7 @@ class WincacheBackendTest extends UnitTestCase
         $identifier = StringUtility::getUniqueId('MyIdentifier');
         $backend->set($identifier, $data);
         $fetchedData = $backend->get($identifier);
-        self::assertEquals($data, $fetchedData, 'Winache backend failed to set and retrieve data');
+        self::assertEquals($data, $fetchedData, 'Wincache backend failed to set and retrieve data');
     }
 
     /**
diff --git a/typo3/sysext/core/Tests/Unit/Charset/CharsetConverterTest.php b/typo3/sysext/core/Tests/Unit/Charset/CharsetConverterTest.php
index 341d4bc24c78d2f2839fbbfe3dce428bf0ee61ec..2b81c7b28d4ab2e257d01c89ff44d2586979fb80 100644
--- a/typo3/sysext/core/Tests/Unit/Charset/CharsetConverterTest.php
+++ b/typo3/sysext/core/Tests/Unit/Charset/CharsetConverterTest.php
@@ -185,7 +185,7 @@ class CharsetConverterTest extends UnitTestCase
     /**
      * @test
      */
-    public function utf8EncodeAlredyUtf8EncodedSign()
+    public function utf8EncodeAlreadyUtf8EncodedSign()
     {
         self::assertSame(
             "\xF0\x9F\x98\x82",
diff --git a/typo3/sysext/core/Tests/Unit/Configuration/FlexForm/FlexFormToolsTest.php b/typo3/sysext/core/Tests/Unit/Configuration/FlexForm/FlexFormToolsTest.php
index 9094b4b5b23862a6243a6cee9c296fb290aa2d0c..07a5b6c5c0ba1ed6379443d27f9569d09ebbfda2 100644
--- a/typo3/sysext/core/Tests/Unit/Configuration/FlexForm/FlexFormToolsTest.php
+++ b/typo3/sysext/core/Tests/Unit/Configuration/FlexForm/FlexFormToolsTest.php
@@ -753,7 +753,7 @@ class FlexFormToolsTest extends UnitTestCase
     /**
      * @test
      */
-    public function getDataStructureIdentifierThrowsExceptionIfResorvedPointerValueIsIntegerButDsFieldNameIsNotConfigured(): void
+    public function getDataStructureIdentifierThrowsExceptionIfReservedPointerValueIsIntegerButDsFieldNameIsNotConfigured(): void
     {
         $fieldTca = [
             'config' => [
diff --git a/typo3/sysext/core/Tests/Unit/Configuration/RichtextTest.php b/typo3/sysext/core/Tests/Unit/Configuration/RichtextTest.php
index ce22d4b7bbafde677c705e2a96428cc1221b26f3..2480dde32c6bad0d56631e9d57384c16ed9d63ec 100644
--- a/typo3/sysext/core/Tests/Unit/Configuration/RichtextTest.php
+++ b/typo3/sysext/core/Tests/Unit/Configuration/RichtextTest.php
@@ -317,7 +317,7 @@ class RichtextTest extends UnitTestCase
                         'types.' => [
                             'textmedia.' => [
                                 'classes.' => [
-                                    'aClass' => 'aTypeSpecifcConfig',
+                                    'aClass' => 'aTypeSpecificConfig',
                                 ],
                                 'editor.' => [
                                     'config.' => [
@@ -333,7 +333,7 @@ class RichtextTest extends UnitTestCase
         $expected = [
             // Config with pagets dots
             'classes.' => [
-                'aClass' => 'aTypeSpecifcConfig',
+                'aClass' => 'aTypeSpecificConfig',
             ],
             'editor.' => [
                 'config.' => [
@@ -343,7 +343,7 @@ class RichtextTest extends UnitTestCase
             'preset' => 'default',
             // Config without pagets dots
             'classes' => [
-                'aClass' => 'aTypeSpecifcConfig',
+                'aClass' => 'aTypeSpecificConfig',
             ],
             'editor' => [
                 'config' => [
@@ -575,7 +575,7 @@ class RichtextTest extends UnitTestCase
                         'overruleMode' => 'default',
                     ],
                 ],
-                'message' => 'single Preset of testRteConfig* defined in Pagetesconfig for default of RTE',
+                'message' => 'single Preset of testRteConfig* defined in PageTSconfig for default of RTE',
             ],
             [
                 'fieldConfig' => [
@@ -607,7 +607,7 @@ class RichtextTest extends UnitTestCase
                         'overruleMode' => 'default',
                     ],
                 ],
-                'message' => 'single Preset of testRteConfig* defined in Pagetesconfig for field of table ',
+                'message' => 'single Preset of testRteConfig* defined in PageTSconfig for field of table ',
             ],
             [
                 'fieldConfig' => [
diff --git a/typo3/sysext/core/Tests/Unit/Core/ApplicationContextTest.php b/typo3/sysext/core/Tests/Unit/Core/ApplicationContextTest.php
index ea8d41cbaf8eb448dfe85d0efa271db04ef41996..9309fa2c68323e370abbd1989b5da8091e32dc8c 100644
--- a/typo3/sysext/core/Tests/Unit/Core/ApplicationContextTest.php
+++ b/typo3/sysext/core/Tests/Unit/Core/ApplicationContextTest.php
@@ -58,7 +58,7 @@ class ApplicationContextTest extends UnitTestCase
     public function forbiddenContexts()
     {
         return [
-            ['MySpecialContexz'],
+            ['MySpecialContext'],
             ['Testing123'],
             ['DevelopmentStuff'],
             ['DevelopmentStuff/FooBar'],
diff --git a/typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PaswordHashTest.php b/typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PasswordHashTest.php
similarity index 99%
rename from typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PaswordHashTest.php
rename to typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PasswordHashTest.php
index f9469c2c090ef252ddaa4e20baa16602623824e4..37c21785a7ee74a2ec9b3bbf295f16cda0add524 100644
--- a/typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PaswordHashTest.php
+++ b/typo3/sysext/core/Tests/Unit/Crypto/PasswordHashing/Pbkdf2PasswordHashTest.php
@@ -21,7 +21,7 @@ use TYPO3\TestingFramework\Core\Unit\UnitTestCase;
 /**
  * Test case
  */
-class Pbkdf2PaswordHashTest extends UnitTestCase
+class Pbkdf2PasswordHashTest extends UnitTestCase
 {
     /**
      * @test
diff --git a/typo3/sysext/core/Tests/Unit/Database/Query/QueryBuilderTest.php b/typo3/sysext/core/Tests/Unit/Database/Query/QueryBuilderTest.php
index 6e6a1b080a65c6e94bf12a315502a06a71c22dbe..a9d168216d0d47ac5cf521517b50be4261e2a400 100644
--- a/typo3/sysext/core/Tests/Unit/Database/Query/QueryBuilderTest.php
+++ b/typo3/sysext/core/Tests/Unit/Database/Query/QueryBuilderTest.php
@@ -733,7 +733,7 @@ class QueryBuilderTest extends UnitTestCase
     /**
      * @test
      */
-    public function setValueWithoudNamedParameterQuotesIdentifierAndDelegatesToConcreteQueryBuilder(): void
+    public function setValueWithoutNamedParameterQuotesIdentifierAndDelegatesToConcreteQueryBuilder(): void
     {
         $this->connection->quoteIdentifier('aField')
             ->shouldBeCalled()
diff --git a/typo3/sysext/core/Tests/Unit/Html/HtmlParserTest.php b/typo3/sysext/core/Tests/Unit/Html/HtmlParserTest.php
index 5d5f261c9f84f0d1ce355510c344e4aacfc5d903..a7ea6e1f865f1383b31beabb5ee0f0699fa147c0 100644
--- a/typo3/sysext/core/Tests/Unit/Html/HtmlParserTest.php
+++ b/typo3/sysext/core/Tests/Unit/Html/HtmlParserTest.php
@@ -226,11 +226,11 @@ class HtmlParserTest extends UnitTestCase
                 'testa<B>test1<I>test2</B>test3</I>testb',
                 'testa<B>test1<I>test2</B>test3</I>testb'
             ],
-            'Superflous tags are removed' => [
+            'Superfluous tags are removed' => [
                 '</B><B><I></B></I></B>',
                 '<B><I></B></I>'
             ],
-            'Superflous tags with content are removed' => [
+            'Superfluous tags with content are removed' => [
                 'test1</B>test2<B>test3<I>test4</B>test5</I>test6</B>test7',
                 'test1test2<B>test3<I>test4</B>test5</I>test6test7'
             ],
diff --git a/typo3/sysext/core/Tests/Unit/Html/RteHtmlParserTest.php b/typo3/sysext/core/Tests/Unit/Html/RteHtmlParserTest.php
index c86dfef7656116a8ab72f96ba84fc28d3fc3dc5a..7c3318c94b3962922ef6860bf28ab09fb46e0811 100644
--- a/typo3/sysext/core/Tests/Unit/Html/RteHtmlParserTest.php
+++ b/typo3/sysext/core/Tests/Unit/Html/RteHtmlParserTest.php
@@ -317,7 +317,7 @@ class RteHtmlParserTest extends UnitTestCase
                 '<h1>block1</h1><p></p><h1>block2</h1>',
                 '<h1>block1</h1>' . CRLF . CRLF . '<h1>block2</h1>',
             ],
-            'Block followed by empty paragraph aand block, linebreak-separated' => [
+            'Block followed by empty paragraph and block, linebreak-separated' => [
                 '<h1>block1</h1>' . CRLF . '<p></p>' . CRLF . '<h1>block2</h1>',
                 '<h1>block1</h1>' . CRLF . CRLF . '<h1>block2</h1>',
             ],
diff --git a/typo3/sysext/core/Tests/Unit/Http/MiddlewareDispatcherTest.php b/typo3/sysext/core/Tests/Unit/Http/MiddlewareDispatcherTest.php
index e149ce629cb0c90c2c6405fc29cc09274aac63e0..975b16bc0b13a9ef3d8b3b73ce4de508909bc533 100644
--- a/typo3/sysext/core/Tests/Unit/Http/MiddlewareDispatcherTest.php
+++ b/typo3/sysext/core/Tests/Unit/Http/MiddlewareDispatcherTest.php
@@ -144,7 +144,7 @@ class MiddlewareDispatcherTest extends UnitTestCase
     /**
      * @test
      */
-    public function canBeExcutedMultipleTimes()
+    public function canBeExecutedMultipleTimes()
     {
         $kernel = new class implements RequestHandlerInterface {
             public function handle(ServerRequestInterface $request): ResponseInterface
diff --git a/typo3/sysext/core/Tests/Unit/Http/ResponseTest.php b/typo3/sysext/core/Tests/Unit/Http/ResponseTest.php
index cc81d97aacfaabd9e1a2150caaf2ce1689ef756e..def958c87b681e3379f7ef2813909c93aac06115 100644
--- a/typo3/sysext/core/Tests/Unit/Http/ResponseTest.php
+++ b/typo3/sysext/core/Tests/Unit/Http/ResponseTest.php
@@ -181,7 +181,7 @@ class ResponseTest extends UnitTestCase
     /**
      * @test
      */
-    public function constructorIgonoresInvalidHeaders()
+    public function constructorIgnoresInvalidHeaders()
     {
         $headers = [
             ['INVALID'],
diff --git a/typo3/sysext/core/Tests/Unit/Http/StreamTest.php b/typo3/sysext/core/Tests/Unit/Http/StreamTest.php
index 79c21a1e36edc62114e3096ea8a666daf694a1a6..5a092953575fae32be1ab44fad649dc95fc2af44 100644
--- a/typo3/sysext/core/Tests/Unit/Http/StreamTest.php
+++ b/typo3/sysext/core/Tests/Unit/Http/StreamTest.php
@@ -48,7 +48,7 @@ class StreamTest extends UnitTestCase
     /**
      * @test
      */
-    public function canInstantiteWithStreamResource()
+    public function canInstantiateWithStreamResource()
     {
         $resource = fopen('php://memory', 'wb+');
         $stream = new Stream($resource);
diff --git a/typo3/sysext/core/Tests/Unit/Imaging/IconRegistryTest.php b/typo3/sysext/core/Tests/Unit/Imaging/IconRegistryTest.php
index 91dcc2094f330655303e8e45cf458d40f81c9704..3abc429ddf163795156aeae60c3e1bf7c4668db8 100644
--- a/typo3/sysext/core/Tests/Unit/Imaging/IconRegistryTest.php
+++ b/typo3/sysext/core/Tests/Unit/Imaging/IconRegistryTest.php
@@ -84,14 +84,14 @@ class IconRegistryTest extends UnitTestCase
      */
     public function registerIconAddNewIconToRegistry()
     {
-        $unregisterdIcon = 'foo-bar-unregistered';
+        $unregisteredIcon = 'foo-bar-unregistered';
         $subject = new IconRegistry();
-        self::assertFalse($subject->isRegistered($unregisterdIcon));
-        $subject->registerIcon($unregisterdIcon, FontawesomeIconProvider::class, [
+        self::assertFalse($subject->isRegistered($unregisteredIcon));
+        $subject->registerIcon($unregisteredIcon, FontawesomeIconProvider::class, [
             'name' => 'pencil',
             'additionalClasses' => 'fa-fw'
         ]);
-        self::assertTrue($subject->isRegistered($unregisterdIcon));
+        self::assertTrue($subject->isRegistered($unregisteredIcon));
     }
 
     /**
@@ -132,7 +132,7 @@ class IconRegistryTest extends UnitTestCase
     /**
      * @test
      */
-    public function getAllRegisteredIconIdentifiersReturnsAnArrayWithIconIdentiefiers()
+    public function getAllRegisteredIconIdentifiersReturnsAnArrayWithIconIdentifiers()
     {
         self::assertIsArray((new IconRegistry)->getAllRegisteredIconIdentifiers());
     }
@@ -221,7 +221,7 @@ class IconRegistryTest extends UnitTestCase
     /**
      * @test
      */
-    public function getIconIdentifierForMimeTypeWithUnknowMimeTypeReturnNull()
+    public function getIconIdentifierForMimeTypeWithUnknownMimeTypeReturnNull()
     {
         $result = (new IconRegistry)->getIconIdentifierForMimeType('bar/foo');
         self::assertNull($result);
diff --git a/typo3/sysext/core/Tests/Unit/Imaging/IconTest.php b/typo3/sysext/core/Tests/Unit/Imaging/IconTest.php
index 77bf1b8497a7d6e5524a57ec8764c8174f26b8fa..7f44e53616d5fb759f67b442121f721c2a2dc0fd 100644
--- a/typo3/sysext/core/Tests/Unit/Imaging/IconTest.php
+++ b/typo3/sysext/core/Tests/Unit/Imaging/IconTest.php
@@ -95,7 +95,7 @@ class IconTest extends UnitTestCase
     /**
      * @test
      */
-    public function getSizedentifierReturnsCorrectIdentifier()
+    public function getSizeIdentifierReturnsCorrectIdentifier()
     {
         self::assertEquals(Icon::SIZE_SMALL, $this->subject->getSize());
     }
diff --git a/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryPeakUsageProcessorTest.php b/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryPeakUsageProcessorTest.php
index 0112f25f606f29d3a4776b9febb3d6bd570961e8..da6d5cb761c27b54088eb4cac676ce66dd45e48b 100644
--- a/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryPeakUsageProcessorTest.php
+++ b/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryPeakUsageProcessorTest.php
@@ -24,7 +24,7 @@ class MemoryPeakUsageProcessorTest extends UnitTestCase
     /**
      * @test
      */
-    public function memoryPeakUsagePRocessorAddsMemoryPeakUsageDataToLogRecord()
+    public function memoryPeakUsageProcessorAddsMemoryPeakUsageDataToLogRecord()
     {
         $logRecord = new \TYPO3\CMS\Core\Log\LogRecord('test.core.log', \TYPO3\CMS\Core\Log\LogLevel::DEBUG, 'test');
         $processor = new \TYPO3\CMS\Core\Log\Processor\MemoryPeakUsageProcessor();
diff --git a/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryUsageProcessorTest.php b/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryUsageProcessorTest.php
index a7cd4d48d43332edce291d2b9c81f49cf12480d9..8777142ca7b72871d9b4961fc92eb7d1ef67e354 100644
--- a/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryUsageProcessorTest.php
+++ b/typo3/sysext/core/Tests/Unit/Log/Processor/MemoryUsageProcessorTest.php
@@ -24,7 +24,7 @@ class MemoryUsageProcessorTest extends UnitTestCase
     /**
      * @test
      */
-    public function memoryUsagePRocessorAddsMemoryUsageDataToLogRecord()
+    public function memoryUsageProcessorAddsMemoryUsageDataToLogRecord()
     {
         $logRecord = new \TYPO3\CMS\Core\Log\LogRecord('test.core.log', \TYPO3\CMS\Core\Log\LogLevel::DEBUG, 'test');
         $processor = new \TYPO3\CMS\Core\Log\Processor\MemoryUsageProcessor();
diff --git a/typo3/sysext/core/Tests/Unit/Pagination/ArrayPaginatorTest.php b/typo3/sysext/core/Tests/Unit/Pagination/ArrayPaginatorTest.php
index 5fc2bfbaf159c555057365e7c2ea56abddd117bd..34d7a9fd703c75ba9417b0b5eb692ef7a5f19b69 100644
--- a/typo3/sysext/core/Tests/Unit/Pagination/ArrayPaginatorTest.php
+++ b/typo3/sysext/core/Tests/Unit/Pagination/ArrayPaginatorTest.php
@@ -124,7 +124,7 @@ class ArrayPaginatorTest extends UnitTestCase
     /**
      * @test
      */
-    public function paginatorProperlyCalulatesOnlyOnePage()
+    public function paginatorProperlyCalculatesOnlyOnePage()
     {
         $paginator = new ArrayPaginator(
             $this->fixture,
diff --git a/typo3/sysext/core/Tests/Unit/Resource/Rendering/VimeoRendererTest.php b/typo3/sysext/core/Tests/Unit/Resource/Rendering/VimeoRendererTest.php
index ce3dc405406a99eec3ed0b32b444aac8969d0df3..cb1db8f9be6a1bc02eeab8e2fef75d5c413d5de8 100644
--- a/typo3/sysext/core/Tests/Unit/Resource/Rendering/VimeoRendererTest.php
+++ b/typo3/sysext/core/Tests/Unit/Resource/Rendering/VimeoRendererTest.php
@@ -147,7 +147,7 @@ class VimeoRendererTest extends UnitTestCase
     /**
      * @test
      */
-    public function renderOutputWithAutoplayAndWithoutControllsIsCorrect()
+    public function renderOutputWithAutoplayAndWithoutControlsIsCorrect()
     {
         /** @var File|\PHPUnit\Framework\MockObject\MockObject $fileResourceMock */
         $fileResourceMock = $this->createMock(File::class);
diff --git a/typo3/sysext/core/Tests/Unit/Resource/Service/ExtractorServiceTest.php b/typo3/sysext/core/Tests/Unit/Resource/Service/ExtractorServiceTest.php
index e21eaf565f2389eb9635c8b3ef38ea745bcc7f07..37dac3375807c69c082d9b96ef49b8a40296beeb 100644
--- a/typo3/sysext/core/Tests/Unit/Resource/Service/ExtractorServiceTest.php
+++ b/typo3/sysext/core/Tests/Unit/Resource/Service/ExtractorServiceTest.php
@@ -30,7 +30,7 @@ class ExtractorServiceTest extends \TYPO3\TestingFramework\Core\Unit\UnitTestCas
     /**
      * @test
      */
-    public function isFileTypeSupportedByExtractorReturnsFalesForFileTypeTextAndExtractorLimitedToFileTypeImage(): void
+    public function isFileTypeSupportedByExtractorReturnsFalseForFileTypeTextAndExtractorLimitedToFileTypeImage(): void
     {
         $fileMock = $this->createMock(File::class);
         $fileMock->expects(self::any())->method('getType')->willReturn(File::FILETYPE_TEXT);
diff --git a/typo3/sysext/core/Tests/Unit/Tree/TableConfiguration/TreeDataProviderFactoryTest.php b/typo3/sysext/core/Tests/Unit/Tree/TableConfiguration/TreeDataProviderFactoryTest.php
index cb3c15af71c657d12b305793ddf24f99db854ea1..b7e10ef56a20d2dc8b9c93d3dfb7b7577f1d8abd 100644
--- a/typo3/sysext/core/Tests/Unit/Tree/TableConfiguration/TreeDataProviderFactoryTest.php
+++ b/typo3/sysext/core/Tests/Unit/Tree/TableConfiguration/TreeDataProviderFactoryTest.php
@@ -73,7 +73,7 @@ class TreeDataProviderFactoryTest extends UnitTestCase
                 ],
                 1288215890
             ],
-            'Tree configuration missing childer and parent field' => [
+            'Tree configuration missing children and parent field' => [
                 [
                     'internal_type' => 'db',
                     'foreign_table' => 'foo',
diff --git a/typo3/sysext/core/Tests/Unit/Utility/MailUtilityTest.php b/typo3/sysext/core/Tests/Unit/Utility/MailUtilityTest.php
index 454e34655bade6525b4a232906c86fa5df9a88a0..b4056aa44156e925f5b4478bc9f5a1f81c8812c9 100644
--- a/typo3/sysext/core/Tests/Unit/Utility/MailUtilityTest.php
+++ b/typo3/sysext/core/Tests/Unit/Utility/MailUtilityTest.php
@@ -30,7 +30,7 @@ class MailUtilityTest extends UnitTestCase
     /**
      * @test
      */
-    public function breakLinesForEmailReturnsEmptyStringIfEmptryStringIsGiven()
+    public function breakLinesForEmailReturnsEmptyStringIfEmptyStringIsGiven()
     {
         self::assertEmpty(MailUtility::breakLinesForEmail(''));
     }
diff --git a/typo3/sysext/core/Tests/Unit/Utility/MathUtilityTest.php b/typo3/sysext/core/Tests/Unit/Utility/MathUtilityTest.php
index 533cd2d2f4b95b5d40a68d34d51e894b326d91a4..f41b953c4a5b22342b9bff5a15def5c6ca2871be 100644
--- a/typo3/sysext/core/Tests/Unit/Utility/MathUtilityTest.php
+++ b/typo3/sysext/core/Tests/Unit/Utility/MathUtilityTest.php
@@ -256,7 +256,7 @@ class MathUtilityTest extends UnitTestCase
             'power' => [8, '2 ^ 3'],
             'three operands with non integer result' => [6.5, '5 + 3 / 2'],
             'three operands with power' => [14, '5 + 3 ^ 2'],
-            'three operads with modulus' => [4, '5 % 2 + 3'],
+            'three operands with modulus' => [4, '5 % 2 + 3'],
             'four operands' => [3, '2 + 6 / 2 - 2'],
             'division by zero when dividing' => ['ERROR: dividing by zero', '2 / 0'],
             'division by zero with modulus' => ['ERROR: dividing by zero', '2 % 0']
diff --git a/typo3/sysext/core/Tests/Unit/Utility/PathUtilityTest.php b/typo3/sysext/core/Tests/Unit/Utility/PathUtilityTest.php
index d56563a7bb924dd755243455e904d1942e6d1f16..ff4a8c025d0caf4336064d889a682ca3134f8dcd 100644
--- a/typo3/sysext/core/Tests/Unit/Utility/PathUtilityTest.php
+++ b/typo3/sysext/core/Tests/Unit/Utility/PathUtilityTest.php
@@ -334,7 +334,7 @@ class PathUtilityTest extends UnitTestCase
                 '/def/../text.txt',
                 '/text.txt'
             ],
-            'absolute windwos path' => [
+            'absolute windows path' => [
                 'C:\def\..\..\test.txt',
                 'C:/test.txt'
             ],
diff --git a/typo3/sysext/core/Tests/Unit/Utility/StringUtilityTest.php b/typo3/sysext/core/Tests/Unit/Utility/StringUtilityTest.php
index 601ae5c2592ecdf53582e241d608119b98fcde12..debd4bd4a0b2b23f007c709443215e40017e79ad 100644
--- a/typo3/sysext/core/Tests/Unit/Utility/StringUtilityTest.php
+++ b/typo3/sysext/core/Tests/Unit/Utility/StringUtilityTest.php
@@ -32,7 +32,7 @@ class StringUtilityTest extends UnitTestCase
     {
         return [
             'match last part of string' => ['hello world', 'world'],
-            'match last char of string' => ['hellod world', 'd'],
+            'match last char of string' => ['hello world', 'd'],
             'match whole string' => ['hello', 'hello'],
             'integer is part of string with same number' => ['24', 24],
             'string is part of integer with same number' => [24, '24'],
@@ -292,32 +292,32 @@ class StringUtilityTest extends UnitTestCase
     public function searchStringWildcardDataProvider(): array
     {
         return [
-            'Simple wildard single character with *' => [
+            'Simple wildcard single character with *' => [
                 'TYPO3',
                 'TY*O3',
                 true
             ],
-            'Simple wildard multiple character with *' => [
+            'Simple wildcard multiple character with *' => [
                 'TYPO3',
                 'T*P*3',
                 true
             ],
-            'Simple wildard multiple character for one placeholder with *' => [
+            'Simple wildcard multiple character for one placeholder with *' => [
                 'TYPO3',
                 'T*3',
                 true
             ],
-            'Simple wildard single character with ?' => [
+            'Simple wildcard single character with ?' => [
                 'TYPO3',
                 'TY?O3',
                 true
             ],
-            'Simple wildard multiple character with ?' => [
+            'Simple wildcard multiple character with ?' => [
                 'TYPO3',
                 'T?P?3',
                 true
             ],
-            'Simple wildard multiple character for one placeholder with ?' => [
+            'Simple wildcard multiple character for one placeholder with ?' => [
                 'TYPO3',
                 'T?3',
                 false
diff --git a/typo3/sysext/core/Tests/UnitDeprecated/Console/CommandRegistryTest.php b/typo3/sysext/core/Tests/UnitDeprecated/Console/CommandRegistryTest.php
index 777ea211d055dc74d2b769433a77a6e4cff5a095..10ee80a3a11910577e3636860c33d4f0ba7a18e6 100644
--- a/typo3/sysext/core/Tests/UnitDeprecated/Console/CommandRegistryTest.php
+++ b/typo3/sysext/core/Tests/UnitDeprecated/Console/CommandRegistryTest.php
@@ -168,7 +168,7 @@ class CommandRegistryTest extends UnitTestCase
     /**
      * @test
      */
-    public function throwsUnknowCommandExceptionIfUnregisteredCommandIsRequested()
+    public function throwsUnknownCommandExceptionIfUnregisteredCommandIsRequested()
     {
         $this->packageManagerProphecy->getActivePackages()->willReturn([]);
diff --git a/typo3/sysext/core/Tests/Unit/Utility/GeneralUtilityTest.php b/typo3/sysext/core/Tests/Unit/Utility/GeneralUtilityTest.php
index cc1daec91543b6628682b2b49d33b82438ca1ad1..b3b59af6a15a93858772e4b9c070f93564224940 100644
--- a/typo3/sysext/core/Tests/Unit/Utility/GeneralUtilityTest.php
+++ b/typo3/sysext/core/Tests/Unit/Utility/GeneralUtilityTest.php
@@ -437,7 +437,7 @@ class GeneralUtilityTest extends UnitTestCase
      * @test
      * @dataProvider normalizeCompressIPv6DataProviderCorrect
      */
-    public function compressIPv6CorrectlyCompressesAdresses($compressed, $normalized)
+    public function compressIPv6CorrectlyCompressesAddresses($compressed, $normalized)
     {
         self::assertEquals($compressed, GeneralUtility::compressIPv6($normalized));
     }
@@ -445,7 +445,7 @@ class GeneralUtilityTest extends UnitTestCase
     /**
      * @test
      */
-    public function compressIPv6CorrectlyCompressesAdressWithSomeAddressOnRightSide()
+    public function compressIPv6CorrectlyCompressesAddressWithSomeAddressOnRightSide()
     {
         if (strtolower(PHP_OS) === 'darwin') {
             self::markTestSkipped('This test does not work on OSX / Darwin OS.');
@@ -835,11 +835,11 @@ class GeneralUtilityTest extends UnitTestCase
             'SI Decimal is omitted for large gigabytes' => [30000000000, 'si', 0, '30 G'],
             'Label for bytes can be exchanged (binary unit)' => [1, ' Foo|||', 0, '1 Foo'],
             'Label for kilobytes can be exchanged (binary unit)' => [1024, '| Foo||', 0, '1.00 Foo'],
-            'Label for megabyes can be exchanged (binary unit)' => [1048576, '|| Foo|', 0, '1.00 Foo'],
+            'Label for megabytes can be exchanged (binary unit)' => [1048576, '|| Foo|', 0, '1.00 Foo'],
             'Label for gigabytes can be exchanged (binary unit)' => [1073741824, '||| Foo', 0, '1.00 Foo'],
             'Label for bytes can be exchanged (decimal unit)' => [1, ' Foo|||', 1000, '1 Foo'],
             'Label for kilobytes can be exchanged (decimal unit)' => [1000, '| Foo||', 1000, '1.00 Foo'],
-            'Label for megabyes can be exchanged (decimal unit)' => [1000000, '|| Foo|', 1000, '1.00 Foo'],
+            'Label for megabytes can be exchanged (decimal unit)' => [1000000, '|| Foo|', 1000, '1.00 Foo'],
             'Label for gigabytes can be exchanged (decimal unit)' => [1000000000, '||| Foo', 1000, '1.00 Foo'],
             'IEC Base is ignored' => [1024, 'iec', 1000, '1.00 Ki'],
             'SI Base is ignored' => [1000, 'si', 1024, '1.00 k'],
@@ -1523,7 +1523,7 @@ class GeneralUtilityTest extends UnitTestCase
      * @test
      * @dataProvider hostnameAndPortDataProvider
      */
-    public function getIndpEnvTypo3HostOnlyParsesHostnamesAndIpAdresses($httpHost, $expectedIp)
+    public function getIndpEnvTypo3HostOnlyParsesHostnamesAndIpAddresses($httpHost, $expectedIp)
     {
         $_SERVER['HTTP_HOST'] = $httpHost;
         self::assertEquals($expectedIp, GeneralUtility::getIndpEnv('TYPO3_HOST_ONLY'));
@@ -1532,7 +1532,7 @@ class GeneralUtilityTest extends UnitTestCase
     /**
      * @test
      */
-    public function isAllowedHostHeaderValueReturnsFalseIfTrusedHostsIsNotConfigured()
+    public function isAllowedHostHeaderValueReturnsFalseIfTrustedHostsIsNotConfigured()
     {
         unset($GLOBALS['TYPO3_CONF_VARS']['SYS']['trustedHostsPattern']);
         self::assertFalse(GeneralUtilityFixture::isAllowedHostHeaderValue('evil.foo.bar'));
@@ -1738,7 +1738,7 @@ class GeneralUtilityTest extends UnitTestCase
      * @test
      * @dataProvider hostnameAndPortDataProvider
      */
-    public function getIndpEnvTypo3PortParsesHostnamesAndIpAdresses($httpHost, $dummy, $expectedPort)
+    public function getIndpEnvTypo3PortParsesHostnamesAndIpAddresses($httpHost, $dummy, $expectedPort)
     {
         $_SERVER['HTTP_HOST'] = $httpHost;
         self::assertEquals($expectedPort, GeneralUtility::getIndpEnv('TYPO3_PORT'));
@@ -1839,7 +1839,7 @@ class GeneralUtilityTest extends UnitTestCase
             'http index.html' => ['http://example.com/index.html'],
             'http index.php' => ['http://www.example.com/index.php'],
             'http test.png' => ['http://www.example/img/test.png'],
-            'http username password querystring and ancher' => ['https://user:pw@www.example.org:80/path?arg=value#fragment'],
+            'http username password querystring and anchor' => ['https://user:pw@www.example.org:80/path?arg=value#fragment'],
             'file' => ['file:///tmp/test.c'],
             'file directory' => ['file://foo/bar'],
             'ftp directory' => ['ftp://ftp.example.com/tmp/'],
@@ -1866,9 +1866,9 @@ class GeneralUtilityTest extends UnitTestCase
     /**
      * Data provider for invalid isValidUrl's
      *
      * @return array Invalid ressource
      */
-    public function isValidUrlInvalidRessourceDataProvider()
+    public function isValidUrlInvalidResourceDataProvider()
     {
         return [
             'http missing colon' => ['http//www.example/wrong/url/'],
@@ -1891,9 +1891,9 @@ class GeneralUtilityTest extends UnitTestCase
 
     /**
      * @test
-     * @dataProvider isValidUrlInvalidRessourceDataProvider
+     * @dataProvider isValidUrlInvalidResourceDataProvider
      */
-    public function validURLReturnsFalseForInvalidRessoure($url)
+    public function validURLReturnsFalseForInvalidResource($url)
     {
         self::assertFalse(GeneralUtility::isValidUrl($url));
     }
@@ -3484,7 +3484,7 @@ class GeneralUtilityTest extends UnitTestCase
             'one times ../ in relative path' => ['dir1/../dir2/script.php', 'dir2/script.php'],
             'one times ../ in absolute path' => ['/dir1/../dir2/script.php', '/dir2/script.php'],
             'consecutive ../' => ['dir1/dir2/dir3/../../../dir4', 'dir4'],
-            'distrubuted ../ with trailing /' => ['dir1/../dir2/dir3/../', 'dir2/'],
+            'distributed ../ with trailing /' => ['dir1/../dir2/dir3/../', 'dir2/'],
             'distributed ../ without trailing /' => ['dir1/../dir2/dir3/..', 'dir2'],
             'multiple distributed and consecutive ../ together' => ['dir1/dir2/dir3/dir4/../../dir5/dir6/dir7/../dir8/', 'dir1/dir2/dir5/dir6/dir8/'],
             'dirname with leading ..' => ['dir1/..dir2/dir3/', 'dir1/..dir2/dir3/'],
@@ -4573,7 +4573,7 @@ class GeneralUtilityTest extends UnitTestCase
      * @todo: The parser run into a memory issue with files bigger 10 MB
      * @todo: This special tests documents the issue. If fixed, this test
      * @todo: should become a data set of xml2ArrayHandlesBigXmlFilesDataProvider()
      * @todo: This test does not pass in all environmnents. It should be evaluated whether this test is really needed or should be removed.
      *
      * @see https://forge.typo3.org/issues/83580
      *
@@ -4581,7 +4581,7 @@ class GeneralUtilityTest extends UnitTestCase
      */
     public function xml2ArrayFailsWithXmlContentBiggerThanTenMegabytes()
     {
-        self::markTestSkipped('This test does not pass in all environmnents. It should be evaluated whether this test is really needed or should be removed.');
+        self::markTestSkipped('This test does not pass in all environments. It should be evaluated whether this test is really needed or should be removed.');
         $cacheManagerProphecy = $this->prophesize(CacheManager::class);
         $cacheProphecy = $this->prophesize(FrontendInterface::class);
         $cacheManagerProphecy->getCache('runtime')->willReturn($cacheProphecy->reveal());
@@ -1866,9 +1866,9 @@ class GeneralUtilityTest extends UnitTestCase
      * Data provider for invalid isValidUrl's
      *
-     * @return array Invalid ressource
+     * @return array Invalid resource
      */
@@ -4573,7 +4573,7 @@ class GeneralUtilityTest extends UnitTestCase
      * @todo: This special tests documents the issue. If fixed, this test
      * @todo: should become a data set of xml2ArrayHandlesBigXmlFilesDataProvider()
-     * @todo: This test does not pass in all environmnents. It should be evaluated whether this test is really needed or should be removed.
+     * @todo: This test does not pass in all environments. It should be evaluated whether this test is really needed or should be removed.
      *
      * @see https://forge.typo3.org/issues/83580